@@ -54,7 +54,7 @@ def extract_times(lang, text, publication_time):
     try:
         annotations = py_heideltime.heideltime(text, lang, "news")
     except IndexError as e:
-        #traceback.print_exc()
+        traceback.print_exc()
         annotations = []
         print()
         print("WARNING: no time expression processed in this document for some bug in py_heideltime.")
