@@ -1,3 +1,6 @@
+import re
+import string
+
 import spacy
 import transformers
 import pandas as pd
@@ -21,29 +24,77 @@ from text2story.annotators.SRL.srl_model.config import SRLModelConfig
 
 ### Global Variables ###
 
-SRL_TYPE_MAPPING = {
-    "TMP": "time",
-    "LOC": "location",
-    "ADV": "theme",  # Adverbial
-    "MNR": "manner",
-    "CAU": "cause",
-    "PRP":"cause",
-    "EXT": "theme",  # should be attribute -> changed for compatibility
-    "DIS": "theme",  # connection of two expressions -> should be theme -> changed for compatibility
-    "PNC": "purpose",
-    "PR": "purpose",
-    "NEG": "theme",  # should be attribute -> changed for compatibility | NEG = negation
-    "DIR": "path",  # should be setting -> changed for compatibility
-    "MOD": "instrument",  # MOD = Modal
-    "PRD": "theme",  # Secondary predicate -> should be attribute -> changed for compatibility
-    "ADJ": "theme",
-    "COM": "agent",  # COM = Comitative -> used to express accompaniment
-    "GOL": "goal",  # GOL = goal
+"""SRL_TYPE_MAPPING = {
+    #"TMP": "time",
+    #"LOC": "location",
+    #"ADV": "theme",  # Adverbial
+    #"MNR": "manner",
+    #"CAU": "cause",
+    #"PRP":"cause",
+    #"EXT": "theme",  # should be attribute -> changed for compatibility
+    #"DIS": "theme",  # connection of two expressions -> should be theme -> changed for compatibility
+    #"PNC": "purpose",
+    #"PR": "purpose",
+    #"NEG": "theme",  # should be attribute -> changed for compatibility | NEG = negation
+    #"DIR": "path",  # should be setting -> changed for compatibility
+    #"MOD": "instrument",  # MOD = Modal
+    #"PRD": "theme",  # Secondary predicate -> should be attribute -> changed for compatibility
+    #"ADJ": "theme",
+    #"COM": "agent",  # COM = Comitative -> used to express accompaniment
+    #"GOL": "goal",  # GOL = goal
     "REC": "instrument",  # REC = reciprocal
     "PAS": "passive", # passive verb
     "NSE": "agent",
-    "TML": "time",
-    "ASP": "theme"
+    #"TML": "time",
+    #"ASP": "theme"
+}"""
+
+SRL_TYPE_MAPPING = {
+    # Time / Location / Path / Goal
+    "TMP": "time",                 # temporal modifier
+    "TML": "time",                 # temporal-locative label variants → still time in practice
+    "LOC": "location",
+    "DIR": "path",                 # direction/path; sometimes "goal" if 'to/into' marks endpoint
+    "GOL": "goal",
+
+    # Cause / Purpose / Reason
+    "CAU": "cause",
+    "PRP": "purpose",              # many tagsets use PRP for purpose; your draft put it under cause
+    "PNC": "purpose",
+    "PR":  "purpose",              # if your data uses PR for purpose, keep it
+
+    # Manner / Means / Instrument / Medium
+    "MNR": "manner",
+    "MEANS": "means",              # (if present in your data)
+    "INS": "instrument",           # (if present)
+    "MED": "medium",               # (if present)
+
+    # Extent / Amount / Distance / Attribute
+    "EXT": "amount",               # degree/extent; if specifically distance, map to "distance"
+    "NEG": "attribute",            # polarity is an attribute, not a role
+    "PRD": "attribute",            # secondary predicate = depictives/resultatives → state/attribute
+    "ADJ": "attribute",            # adjectival predication/modification → attribute
+    "ASP": "attribute",            # aspectual operator (or create SRLINK_aspect if you prefer)
+    # If you keep ADV as a bucket:
+    "ADV": "manner",               # generic adverbials → prefer "manner" over "theme"
+
+    # Participant relations
+    "COM": "partner",              # comitative (with) → accompaniment
+    "REC": "partner",              # reciprocal (each other) → symmetric co-participant
+    "NSE": "agent",                # ⚠️ Ambiguous tag in some corpora; confirm your tagset definition
+    "AGT": "agent",                # (if present)
+    "PAT": "patient",              # (if present)
+    "THM": "theme",                # (if present)
+
+    # Voice / Modality / Discourse → not roles
+    "PAS": "attribute",            # voice/diathesis → better as attribute (or SRLINK_voice)
+    "MOD": "attribute",            # modality (can/could/might) → not instrument
+    "DIS": "attribute",            # discourse connective → not a thematic role
+
+    # Other plausible mappings in your inventory
+    # "SRC": "source",             # if present
+    # "GOL": "goal",               # already mapped above
+    # "PRP": "purpose",            # already mapped above
 }
 pipeline = {}
 
@@ -82,7 +133,8 @@ def load(lang):
         pipeline['srl_en'] =  transformers.pipeline("srl", model=model, tokenizer=tokenizer, pipeline_class=SrlPipeline, lang="en")
 
         #pipeline["srl_re_tags"] = r"[BI]-(A\d|ARG\d|AM-[A-Z]+|ARGM-[A-Z]+)"
-        pipeline["srl_re_tags"] = r"[BI]-(R-)?(A\d|ARG\d|AM-[A-Z]+|ARGM-[A-Z]+)"
+        #pipeline["srl_re_tags"] = r"[BI]-(C-)?(R-)?(A\d|ARG\d|AM-[A-Z]+|ARGM-[A-Z]+)"
+        pipeline["srl_re_tags"] = r"[BI]-(?:C-)?(?:R-)?(?:A\d|ARG\d|AM-[A-Z]+|ARGM-[A-Z]+)"
         pipeline["ARGM_STR"] = "ARGM"
 
         # this coreference model is too heavy. Analyze another model to fit here
@@ -104,14 +156,24 @@ def process_srl_output(srl_output_list):
         for verb, (labels, tokens_with_labels) in srl_output.items():
             tokens = []
             predictions = []
-
+            new_line_flag = False
             for token, label in tokens_with_labels:
                 # Ignore <s> and </s> tokens
                 if token not in ['<s>', '</s>']:
-                    # Remove the leading extra token and add to the list
-                    cleaned_token = token[1:] if token.startswith('Ġ') else token
-                    tokens.append(cleaned_token)
-                    predictions.append(label)
+                    # Remove the leading extra token and add to new token
+                    if token.startswith('Ġ') or new_line_flag:
+                         cleaned_token = token.replace('Ġ','')
+                         tokens.append(cleaned_token)
+                         predictions.append(label)
+                         new_line_flag = False
+                    else:
+                        if token == 'Ċ':
+                            new_line_flag = True
+                            continue
+                        # this token is a continuation of the token before
+                        tokens[-1] += token
+
+
 
             output_dict = {
                 "tokens": tokens,
@@ -239,7 +301,7 @@ def _normalize_sent_tags(sentence_df):
         # b) - ARGM e ARG (o último e mais especifico tem prio)
         # TODO: em português as tags estao ligeiramente diferentes:
         # B-AM-TMP, B-A1, I-A2, etc
-        arg_words = word_vals[word_vals.str.contains(pipeline["srl_re_tags"])]
+        arg_words = word_vals[word_vals.str.contains(pipeline["srl_re_tags"], regex=True)]
         if arg_words.shape[0] != 0:
             normalized_tags.append(arg_words.iloc[-1])  # desempate entre dois ARGM-X diferentes
             begin_tags.append(arg_words.iloc[-1].startswith("B"))
@@ -371,13 +433,39 @@ def _srl_by_participant(srl_by_token, text, char_offset):
 
         char_spans = []
         for token in rows.index:
-            char_offset = text.find(token, char_offset)
-            char_spans.append(char_offset)
-            char_offset += len(token)
+            if all(c in string.punctuation or c.isspace() for c in token):
+                # Pure punctuation - literal search
+                pos = text.find(token, char_offset)
+                if pos != -1:
+                    char_spans.append((pos, pos + len(token)))
+                    char_offset = pos + len(token)
+                else:
+                    char_spans.append(-1)
+            else:
+                # Strip all punctuation from both ends to get the word part
+                word_part = token.strip(string.punctuation)
+
+                if word_part:
+                    pattern = r'\b' + re.escape(word_part) + r'\b'
+                    match = re.search(pattern, text[char_offset:])
+
+                    if match:
+                        start_match = char_offset + match.start()
+                        end_match = char_offset + match.end()
+
+                        char_spans.append((start_match, end_match))
+                        #char_offset += len(word_part) # raises error if there is punctuation in the end
+                        #char_offset += len(token) # raises eror if there is punctuation in the start of token
+                        char_offset = end_match
+                    else:
+                        char_spans.append(-1)
+                else:
+                    char_spans.append(-1)
+                #print("-->", char_spans, "--", token)
 
         result_list.append({
             "participant": ' '.join(rows.index), "sem_role_type": sem_role_type,
-            "char_span": (char_spans[0], char_spans[-1] + len(token))
+            "char_span": (char_spans[0][0], char_spans[-1][1]) # the start of the first token in the span, and the end of the last token in the span
         })
 
     return result_list, char_offset
@@ -426,6 +514,7 @@ def _srl_pipeline(sentence_df, text, char_offset, verb_tags, event_threshold=3):
     df_by_participant, character_offset = _srl_by_participant(df, text, char_offset)
 
     return df_by_participant, character_offset
+
 def get_participant_tags(text, participant_lst, lang):
     """
     it adds POS tags and NER tags to the participant list
@@ -468,7 +557,7 @@ def get_participant_tags(text, participant_lst, lang):
 
             tagged_participants_lst.append(((tok.idx, tok.idx + len(tok.text)),tok.pos_,"UNDEF"))
 
-    # it is possible that some participant was not found by the bsearch?
+    # it is possible that some participant was not found by the bsearch? YES
     for idx in range(len(participant_lst)):
         tagged_participants_lst.append(tagged_participants[idx])
 
